@@ -5,9 +5,9 @@ import os
 try:
     from cltk.corpus.greek.beta_to_unicode import Replacer
 except ModuleNotFoundError:
-    CLTK_NOT_FOUND = True
+    CLTK_NOT_FOUND = 1
 else:
-    CLTK_NOT_FOUND = False
+    CLTK_NOT_FOUND = 0
 
 FILE_DIR = os.path.split(__file__)[0]
 UNI_BETA_DICT = {}
